import { NamedCreateRuleMeta } from "@typescript-eslint/utils/eslint-utils";
import { RuleContext, RuleListener } from "@typescript-eslint/utils/ts-eslint";
import { Immutability } from "is-immutable-type";
/**
 * Any custom rule meta properties.
 */
type NamedCreateRuleCustomMeta<T extends string, Options extends BaseOptions> = Omit<NamedCreateRuleMeta<T, Options>, "docs"> & {
    docs: {
        /**
         * Used for creating category configs and splitting the README rules list into sub-lists.
         */
        category: "Currying" | "No Exceptions" | "No Mutations" | "No Other Paradigms" | "No Statements" | "Stylistic";
        recommended: "recommended" | "strict" | false;
        recommendedSeverity: "error" | "warn";
    } & Omit<NamedCreateRuleMeta<T, Options>["docs"], "recommended">;
};
/**
 * All options must extends this type.
 */
type BaseOptions = ReadonlyArray<unknown>;
// eslint-disable-next-line functional/no-mixed-types
type RuleDefinition<MessageIds extends string, Options extends BaseOptions> = {
    readonly defaultOptions: Options;
    readonly meta: NamedCreateRuleCustomMeta<MessageIds, Options>;
    readonly create: (context: Readonly<RuleContext<MessageIds, Options>>) => RuleListener;
};
/**
 * The option to ignore patterns.
 */
type IgnoreIdentifierPatternOption = Readonly<{
    ignoreIdentifierPattern?: ReadonlyArray<string> | string;
}>;
/**
 * How the actual immutability should be compared to the given immutability.
 */
declare enum RuleEnforcementComparator {
    Less = -2,
    AtMost = -1,
    Exactly = 0,
    AtLeast = 1,
    More = 2
}
type FixerConfigRaw = {
    pattern: string;
    replace: string;
};
/**
 * The options this rule can take.
 */
type Options = [
    IgnoreIdentifierPatternOption & {
        rules: Array<{
            identifiers: string | string[];
            immutability: Exclude<Immutability | keyof typeof Immutability, "Unknown">;
            comparator?: RuleEnforcementComparator | keyof typeof RuleEnforcementComparator;
            fixer?: FixerConfigRaw | FixerConfigRaw[] | false;
        }>;
        ignoreInterfaces: boolean;
    }
];
declare const _default: {
    readonly configs: {
        all: {
            plugins: {
                functional: {
                    meta: {
                        readonly name: "eslint-plugin-functional";
                        readonly version: "0.0.0-development";
                    };
                    rules: {
                        "functional-parameters": RuleDefinition<"arguments" | "restParam" | "paramCountAtLeastOne" | "paramCountExactlyOne", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & Readonly<{
                            ignorePrefixSelector?: string | readonly string[];
                        }> & {
                            allowRestParameter: boolean;
                            allowArgumentsKeyword: boolean;
                            enforceParameterCount: false | ("atLeastOne" | "exactlyOne") | {
                                count: "atLeastOne" | "exactlyOne";
                                ignoreLambdaExpression: boolean;
                                ignoreIIFE: boolean;
                                ignoreGettersAndSetters: boolean;
                            };
                        }]>;
                        "immutable-data": RuleDefinition<"object" | "array" | "generic", [Readonly<{
                            ignoreAccessorPattern?: string | readonly string[];
                        }> & Readonly<{
                            ignoreClasses: boolean | "fieldsOnly";
                        }> & Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            ignoreImmediateMutation: boolean;
                            ignoreNonConstDeclarations: boolean | {
                                treatParametersAsConst: boolean;
                            };
                        }]>;
                        "no-classes": RuleDefinition<"generic", [{}]>;
                        "no-conditional-statements": RuleDefinition<"incompleteBranch" | "incompleteIf" | "incompleteSwitch" | "unexpectedIf" | "unexpectedSwitch", [{
                            allowReturningBranches: boolean | "ifExhaustive";
                        }]>;
                        "no-expression-statements": RuleDefinition<"generic", [Readonly<{
                            ignoreCodePattern?: string | readonly string[];
                        }> & {
                            ignoreVoid: boolean;
                            ignoreSelfReturning: boolean;
                        }]>;
                        "no-let": RuleDefinition<"generic", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            allowInForLoopInit: boolean;
                            allowInFunctions: boolean;
                        }]>;
                        "no-loop-statements": RuleDefinition<"generic", [{}]>;
                        "no-mixed-types": RuleDefinition<"generic", [{
                            checkInterfaces: boolean;
                            checkTypeLiterals: boolean;
                        }]>;
                        "no-promise-reject": RuleDefinition<"generic", [{}]>;
                        "no-return-void": RuleDefinition<"generic", [{
                            allowNull: boolean;
                            allowUndefined: boolean;
                            ignoreInferredTypes: boolean;
                        }]>;
                        "no-this-expressions": RuleDefinition<"generic", [{}]>;
                        "no-throw-statements": RuleDefinition<"generic", [{
                            allowInAsyncFunctions: boolean;
                        }]>;
                        "no-try-statements": RuleDefinition<"catch" | "finally", [{
                            allowCatch: boolean;
                            allowFinally: boolean;
                        }]>;
                        "prefer-immutable-types": RuleDefinition<"returnType" | "parameter" | "variable" | "propertyImmutability" | "propertyModifier", [Readonly<{
                            ignoreClasses: boolean | "fieldsOnly";
                        }> & {
                            enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                            ignoreInferredTypes: boolean;
                            ignoreNamePattern?: string | string[];
                            ignoreTypePattern?: string | string[];
                        } & {
                            parameters?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            }>;
                            returnTypes?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            }>;
                            variables?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            } & {
                                ignoreInFunctions?: boolean;
                            }>;
                            fixer?: Partial<Record<"ReadonlyShallow" | "ReadonlyDeep" | "Immutable", {
                                pattern: string;
                                replace: string;
                            } | {
                                pattern: string;
                                replace: string;
                            }[] | undefined>>;
                            suggestions?: Partial<Record<"ReadonlyShallow" | "ReadonlyDeep" | "Immutable", {
                                pattern: string;
                                replace: string;
                            }[][] | undefined>>;
                        }]>;
                        "prefer-property-signatures": RuleDefinition<"generic", [{
                            ignoreIfReadonlyWrapped: boolean;
                        }]>;
                        "prefer-readonly-type": RuleDefinition<"type" | "array" | "property" | "implicit" | "tuple", [{
                            allowLocalMutation: boolean;
                            allowMutableReturnType: boolean;
                            checkImplicit: boolean;
                            ignoreCollections: boolean;
                            ignoreClass: boolean | "fieldsOnly";
                            ignoreInterface: boolean;
                            ignorePattern?: string | string[];
                        }]>;
                        "prefer-tacit": RuleDefinition<"generic", []>;
                        "readonly-type": RuleDefinition<"generic" | "keyword", ["generic" | "keyword"]>;
                        "type-declaration-immutability": RuleDefinition<"Less" | "AtMost" | "Exactly" | "AtLeast" | "More", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            rules: {
                                identifiers: string | string[];
                                immutability: import("is-immutable-type").Immutability | "Mutable" | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating";
                                comparator?: RuleEnforcementComparator | "Less" | "AtMost" | "Exactly" | "AtLeast" | "More";
                                fixer?: false | {
                                    pattern: string;
                                    replace: string;
                                } | {
                                    pattern: string;
                                    replace: string;
                                }[];
                            }[];
                            ignoreInterfaces: boolean;
                        }]>;
                    };
                };
            };
            rules: {
                [x: string]: "error" | "warn";
            };
        };
        lite: {
            plugins: {
                functional: {
                    meta: {
                        readonly name: "eslint-plugin-functional";
                        readonly version: "0.0.0-development";
                    };
                    rules: {
                        "functional-parameters": RuleDefinition<"arguments" | "restParam" | "paramCountAtLeastOne" | "paramCountExactlyOne", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & Readonly<{
                            ignorePrefixSelector?: string | readonly string[];
                        }> & {
                            allowRestParameter: boolean;
                            allowArgumentsKeyword: boolean;
                            enforceParameterCount: false | ("atLeastOne" | "exactlyOne") | {
                                count: "atLeastOne" | "exactlyOne";
                                ignoreLambdaExpression: boolean;
                                ignoreIIFE: boolean;
                                ignoreGettersAndSetters: boolean;
                            };
                        }]>;
                        "immutable-data": RuleDefinition<"object" | "array" | "generic", [Readonly<{
                            ignoreAccessorPattern?: string | readonly string[];
                        }> & Readonly<{
                            ignoreClasses: boolean | "fieldsOnly";
                        }> & Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            ignoreImmediateMutation: boolean;
                            ignoreNonConstDeclarations: boolean | {
                                treatParametersAsConst: boolean;
                            };
                        }]>;
                        "no-classes": RuleDefinition<"generic", [{}]>;
                        "no-conditional-statements": RuleDefinition<"incompleteBranch" | "incompleteIf" | "incompleteSwitch" | "unexpectedIf" | "unexpectedSwitch", [{
                            allowReturningBranches: boolean | "ifExhaustive";
                        }]>;
                        "no-expression-statements": RuleDefinition<"generic", [Readonly<{
                            ignoreCodePattern?: string | readonly string[];
                        }> & {
                            ignoreVoid: boolean;
                            ignoreSelfReturning: boolean;
                        }]>;
                        "no-let": RuleDefinition<"generic", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            allowInForLoopInit: boolean;
                            allowInFunctions: boolean;
                        }]>;
                        "no-loop-statements": RuleDefinition<"generic", [{}]>;
                        "no-mixed-types": RuleDefinition<"generic", [{
                            checkInterfaces: boolean;
                            checkTypeLiterals: boolean;
                        }]>;
                        "no-promise-reject": RuleDefinition<"generic", [{}]>;
                        "no-return-void": RuleDefinition<"generic", [{
                            allowNull: boolean;
                            allowUndefined: boolean;
                            ignoreInferredTypes: boolean;
                        }]>;
                        "no-this-expressions": RuleDefinition<"generic", [{}]>;
                        "no-throw-statements": RuleDefinition<"generic", [{
                            allowInAsyncFunctions: boolean;
                        }]>;
                        "no-try-statements": RuleDefinition<"catch" | "finally", [{
                            allowCatch: boolean;
                            allowFinally: boolean;
                        }]>;
                        "prefer-immutable-types": RuleDefinition<"returnType" | "parameter" | "variable" | "propertyImmutability" | "propertyModifier", [Readonly<{
                            ignoreClasses: boolean | "fieldsOnly";
                        }> & {
                            enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                            ignoreInferredTypes: boolean;
                            ignoreNamePattern?: string | string[];
                            ignoreTypePattern?: string | string[];
                        } & {
                            parameters?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            }>;
                            returnTypes?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            }>;
                            variables?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            } & {
                                ignoreInFunctions?: boolean;
                            }>;
                            fixer?: Partial<Record<"ReadonlyShallow" | "ReadonlyDeep" | "Immutable", {
                                pattern: string;
                                replace: string;
                            } | {
                                pattern: string;
                                replace: string;
                            }[] | undefined>>;
                            suggestions?: Partial<Record<"ReadonlyShallow" | "ReadonlyDeep" | "Immutable", {
                                pattern: string;
                                replace: string;
                            }[][] | undefined>>;
                        }]>;
                        "prefer-property-signatures": RuleDefinition<"generic", [{
                            ignoreIfReadonlyWrapped: boolean;
                        }]>;
                        "prefer-readonly-type": RuleDefinition<"type" | "array" | "property" | "implicit" | "tuple", [{
                            allowLocalMutation: boolean;
                            allowMutableReturnType: boolean;
                            checkImplicit: boolean;
                            ignoreCollections: boolean;
                            ignoreClass: boolean | "fieldsOnly";
                            ignoreInterface: boolean;
                            ignorePattern?: string | string[];
                        }]>;
                        "prefer-tacit": RuleDefinition<"generic", []>;
                        "readonly-type": RuleDefinition<"generic" | "keyword", ["generic" | "keyword"]>;
                        "type-declaration-immutability": RuleDefinition<"Less" | "AtMost" | "Exactly" | "AtLeast" | "More", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            rules: {
                                identifiers: string | string[];
                                immutability: import("is-immutable-type").Immutability | "Mutable" | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating";
                                comparator?: RuleEnforcementComparator | "Less" | "AtMost" | "Exactly" | "AtLeast" | "More";
                                fixer?: false | {
                                    pattern: string;
                                    replace: string;
                                } | {
                                    pattern: string;
                                    replace: string;
                                }[];
                            }[];
                            ignoreInterfaces: boolean;
                        }]>;
                    };
                };
            };
            rules: {
                "functional/functional-parameters": ["error", {
                    enforceParameterCount: boolean;
                }];
                "functional/immutable-data": ["error", {
                    ignoreClasses: string;
                }];
                "functional/no-conditional-statements": "off";
                "functional/no-expression-statements": "off";
                "functional/prefer-immutable-types": ["error", {
                    enforcement: string;
                    ignoreInferredTypes: boolean;
                    parameters: {
                        enforcement: string;
                    };
                }];
                "functional/no-let": ["error", {
                    allowInForLoopInit: boolean;
                }];
                "functional/no-this-expressions": "off";
                "functional/no-throw-statements": ["error", {
                    allowInAsyncFunctions: boolean;
                }];
                "functional/no-try-statements": "off";
                "functional/type-declaration-immutability": ["error", {
                    rules: ({
                        identifiers: string[];
                        immutability: import("is-immutable-type").Immutability;
                        comparator: RuleEnforcementComparator;
                        fixer?: never;
                    } | {
                        identifiers: string[];
                        immutability: import("is-immutable-type").Immutability;
                        comparator: RuleEnforcementComparator;
                        fixer: {
                            pattern: string;
                            replace: string;
                        }[];
                    })[];
                }];
            };
        };
        recommended: {
            plugins: {
                functional: {
                    meta: {
                        readonly name: "eslint-plugin-functional";
                        readonly version: "0.0.0-development";
                    };
                    rules: {
                        "functional-parameters": RuleDefinition<"arguments" | "restParam" | "paramCountAtLeastOne" | "paramCountExactlyOne", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & Readonly<{
                            ignorePrefixSelector?: string | readonly string[];
                        }> & {
                            allowRestParameter: boolean;
                            allowArgumentsKeyword: boolean;
                            enforceParameterCount: false | ("atLeastOne" | "exactlyOne") | {
                                count: "atLeastOne" | "exactlyOne";
                                ignoreLambdaExpression: boolean;
                                ignoreIIFE: boolean;
                                ignoreGettersAndSetters: boolean;
                            };
                        }]>;
                        "immutable-data": RuleDefinition<"object" | "array" | "generic", [Readonly<{
                            ignoreAccessorPattern?: string | readonly string[];
                        }> & Readonly<{
                            ignoreClasses: boolean | "fieldsOnly";
                        }> & Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            ignoreImmediateMutation: boolean;
                            ignoreNonConstDeclarations: boolean | {
                                treatParametersAsConst: boolean;
                            };
                        }]>;
                        "no-classes": RuleDefinition<"generic", [{}]>;
                        "no-conditional-statements": RuleDefinition<"incompleteBranch" | "incompleteIf" | "incompleteSwitch" | "unexpectedIf" | "unexpectedSwitch", [{
                            allowReturningBranches: boolean | "ifExhaustive";
                        }]>;
                        "no-expression-statements": RuleDefinition<"generic", [Readonly<{
                            ignoreCodePattern?: string | readonly string[];
                        }> & {
                            ignoreVoid: boolean;
                            ignoreSelfReturning: boolean;
                        }]>;
                        "no-let": RuleDefinition<"generic", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            allowInForLoopInit: boolean;
                            allowInFunctions: boolean;
                        }]>;
                        "no-loop-statements": RuleDefinition<"generic", [{}]>;
                        "no-mixed-types": RuleDefinition<"generic", [{
                            checkInterfaces: boolean;
                            checkTypeLiterals: boolean;
                        }]>;
                        "no-promise-reject": RuleDefinition<"generic", [{}]>;
                        "no-return-void": RuleDefinition<"generic", [{
                            allowNull: boolean;
                            allowUndefined: boolean;
                            ignoreInferredTypes: boolean;
                        }]>;
                        "no-this-expressions": RuleDefinition<"generic", [{}]>;
                        "no-throw-statements": RuleDefinition<"generic", [{
                            allowInAsyncFunctions: boolean;
                        }]>;
                        "no-try-statements": RuleDefinition<"catch" | "finally", [{
                            allowCatch: boolean;
                            allowFinally: boolean;
                        }]>;
                        "prefer-immutable-types": RuleDefinition<"returnType" | "parameter" | "variable" | "propertyImmutability" | "propertyModifier", [Readonly<{
                            ignoreClasses: boolean | "fieldsOnly";
                        }> & {
                            enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                            ignoreInferredTypes: boolean;
                            ignoreNamePattern?: string | string[];
                            ignoreTypePattern?: string | string[];
                        } & {
                            parameters?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            }>;
                            returnTypes?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            }>;
                            variables?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            } & {
                                ignoreInFunctions?: boolean;
                            }>;
                            fixer?: Partial<Record<"ReadonlyShallow" | "ReadonlyDeep" | "Immutable", {
                                pattern: string;
                                replace: string;
                            } | {
                                pattern: string;
                                replace: string;
                            }[] | undefined>>;
                            suggestions?: Partial<Record<"ReadonlyShallow" | "ReadonlyDeep" | "Immutable", {
                                pattern: string;
                                replace: string;
                            }[][] | undefined>>;
                        }]>;
                        "prefer-property-signatures": RuleDefinition<"generic", [{
                            ignoreIfReadonlyWrapped: boolean;
                        }]>;
                        "prefer-readonly-type": RuleDefinition<"type" | "array" | "property" | "implicit" | "tuple", [{
                            allowLocalMutation: boolean;
                            allowMutableReturnType: boolean;
                            checkImplicit: boolean;
                            ignoreCollections: boolean;
                            ignoreClass: boolean | "fieldsOnly";
                            ignoreInterface: boolean;
                            ignorePattern?: string | string[];
                        }]>;
                        "prefer-tacit": RuleDefinition<"generic", []>;
                        "readonly-type": RuleDefinition<"generic" | "keyword", ["generic" | "keyword"]>;
                        "type-declaration-immutability": RuleDefinition<"Less" | "AtMost" | "Exactly" | "AtLeast" | "More", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            rules: {
                                identifiers: string | string[];
                                immutability: import("is-immutable-type").Immutability | "Mutable" | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating";
                                comparator?: RuleEnforcementComparator | "Less" | "AtMost" | "Exactly" | "AtLeast" | "More";
                                fixer?: false | {
                                    pattern: string;
                                    replace: string;
                                } | {
                                    pattern: string;
                                    replace: string;
                                }[];
                            }[];
                            ignoreInterfaces: boolean;
                        }]>;
                    };
                };
            };
            rules: {
                "functional/functional-parameters": ["error", {
                    enforceParameterCount: {
                        ignoreLambdaExpression: boolean;
                        ignoreIIFE: boolean;
                        ignoreGettersAndSetters: boolean;
                    };
                }];
                "functional/no-conditional-statements": ["error", {
                    allowReturningBranches: boolean;
                }];
                "functional/no-let": ["error", {
                    allowInForLoopInit: boolean;
                }];
                "functional/no-this-expressions": "off";
                "functional/no-throw-statements": ["error", {
                    allowInAsyncFunctions: boolean;
                }];
                "functional/no-try-statements": "off";
                "functional/prefer-immutable-types": ["error", {
                    enforcement: string;
                    ignoreInferredTypes: boolean;
                    parameters: {
                        enforcement: string;
                    };
                }];
                "functional/type-declaration-immutability": ["error", {
                    rules: ({
                        identifiers: string[];
                        immutability: import("is-immutable-type").Immutability;
                        comparator: RuleEnforcementComparator;
                        fixer?: never;
                    } | {
                        identifiers: string[];
                        immutability: import("is-immutable-type").Immutability;
                        comparator: RuleEnforcementComparator;
                        fixer: {
                            pattern: string;
                            replace: string;
                        }[];
                    })[];
                }];
            };
        };
        strict: {
            plugins: {
                functional: {
                    meta: {
                        readonly name: "eslint-plugin-functional";
                        readonly version: "0.0.0-development";
                    };
                    rules: {
                        "functional-parameters": RuleDefinition<"arguments" | "restParam" | "paramCountAtLeastOne" | "paramCountExactlyOne", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & Readonly<{
                            ignorePrefixSelector?: string | readonly string[];
                        }> & {
                            allowRestParameter: boolean;
                            allowArgumentsKeyword: boolean;
                            enforceParameterCount: false | ("atLeastOne" | "exactlyOne") | {
                                count: "atLeastOne" | "exactlyOne";
                                ignoreLambdaExpression: boolean;
                                ignoreIIFE: boolean;
                                ignoreGettersAndSetters: boolean;
                            };
                        }]>;
                        "immutable-data": RuleDefinition<"object" | "array" | "generic", [Readonly<{
                            ignoreAccessorPattern?: string | readonly string[];
                        }> & Readonly<{
                            ignoreClasses: boolean | "fieldsOnly";
                        }> & Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            ignoreImmediateMutation: boolean;
                            ignoreNonConstDeclarations: boolean | {
                                treatParametersAsConst: boolean;
                            };
                        }]>;
                        "no-classes": RuleDefinition<"generic", [{}]>;
                        "no-conditional-statements": RuleDefinition<"incompleteBranch" | "incompleteIf" | "incompleteSwitch" | "unexpectedIf" | "unexpectedSwitch", [{
                            allowReturningBranches: boolean | "ifExhaustive";
                        }]>;
                        "no-expression-statements": RuleDefinition<"generic", [Readonly<{
                            ignoreCodePattern?: string | readonly string[];
                        }> & {
                            ignoreVoid: boolean;
                            ignoreSelfReturning: boolean;
                        }]>;
                        "no-let": RuleDefinition<"generic", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            allowInForLoopInit: boolean;
                            allowInFunctions: boolean;
                        }]>;
                        "no-loop-statements": RuleDefinition<"generic", [{}]>;
                        "no-mixed-types": RuleDefinition<"generic", [{
                            checkInterfaces: boolean;
                            checkTypeLiterals: boolean;
                        }]>;
                        "no-promise-reject": RuleDefinition<"generic", [{}]>;
                        "no-return-void": RuleDefinition<"generic", [{
                            allowNull: boolean;
                            allowUndefined: boolean;
                            ignoreInferredTypes: boolean;
                        }]>;
                        "no-this-expressions": RuleDefinition<"generic", [{}]>;
                        "no-throw-statements": RuleDefinition<"generic", [{
                            allowInAsyncFunctions: boolean;
                        }]>;
                        "no-try-statements": RuleDefinition<"catch" | "finally", [{
                            allowCatch: boolean;
                            allowFinally: boolean;
                        }]>;
                        "prefer-immutable-types": RuleDefinition<"returnType" | "parameter" | "variable" | "propertyImmutability" | "propertyModifier", [Readonly<{
                            ignoreClasses: boolean | "fieldsOnly";
                        }> & {
                            enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                            ignoreInferredTypes: boolean;
                            ignoreNamePattern?: string | string[];
                            ignoreTypePattern?: string | string[];
                        } & {
                            parameters?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            }>;
                            returnTypes?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            }>;
                            variables?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            } & {
                                ignoreInFunctions?: boolean;
                            }>;
                            fixer?: Partial<Record<"ReadonlyShallow" | "ReadonlyDeep" | "Immutable", {
                                pattern: string;
                                replace: string;
                            } | {
                                pattern: string;
                                replace: string;
                            }[] | undefined>>;
                            suggestions?: Partial<Record<"ReadonlyShallow" | "ReadonlyDeep" | "Immutable", {
                                pattern: string;
                                replace: string;
                            }[][] | undefined>>;
                        }]>;
                        "prefer-property-signatures": RuleDefinition<"generic", [{
                            ignoreIfReadonlyWrapped: boolean;
                        }]>;
                        "prefer-readonly-type": RuleDefinition<"type" | "array" | "property" | "implicit" | "tuple", [{
                            allowLocalMutation: boolean;
                            allowMutableReturnType: boolean;
                            checkImplicit: boolean;
                            ignoreCollections: boolean;
                            ignoreClass: boolean | "fieldsOnly";
                            ignoreInterface: boolean;
                            ignorePattern?: string | string[];
                        }]>;
                        "prefer-tacit": RuleDefinition<"generic", []>;
                        "readonly-type": RuleDefinition<"generic" | "keyword", ["generic" | "keyword"]>;
                        "type-declaration-immutability": RuleDefinition<"Less" | "AtMost" | "Exactly" | "AtLeast" | "More", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            rules: {
                                identifiers: string | string[];
                                immutability: import("is-immutable-type").Immutability | "Mutable" | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating";
                                comparator?: RuleEnforcementComparator | "Less" | "AtMost" | "Exactly" | "AtLeast" | "More";
                                fixer?: false | {
                                    pattern: string;
                                    replace: string;
                                } | {
                                    pattern: string;
                                    replace: string;
                                }[];
                            }[];
                            ignoreInterfaces: boolean;
                        }]>;
                    };
                };
            };
            rules: {
                [k: string]: "error" | "warn";
            };
        };
        off: {
            plugins: {
                functional: {
                    meta: {
                        readonly name: "eslint-plugin-functional";
                        readonly version: "0.0.0-development";
                    };
                    rules: {
                        "functional-parameters": RuleDefinition<"arguments" | "restParam" | "paramCountAtLeastOne" | "paramCountExactlyOne", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & Readonly<{
                            ignorePrefixSelector?: string | readonly string[];
                        }> & {
                            allowRestParameter: boolean;
                            allowArgumentsKeyword: boolean;
                            enforceParameterCount: false | ("atLeastOne" | "exactlyOne") | {
                                count: "atLeastOne" | "exactlyOne";
                                ignoreLambdaExpression: boolean;
                                ignoreIIFE: boolean;
                                ignoreGettersAndSetters: boolean;
                            };
                        }]>;
                        "immutable-data": RuleDefinition<"object" | "array" | "generic", [Readonly<{
                            ignoreAccessorPattern?: string | readonly string[];
                        }> & Readonly<{
                            ignoreClasses: boolean | "fieldsOnly";
                        }> & Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            ignoreImmediateMutation: boolean;
                            ignoreNonConstDeclarations: boolean | {
                                treatParametersAsConst: boolean;
                            };
                        }]>;
                        "no-classes": RuleDefinition<"generic", [{}]>;
                        "no-conditional-statements": RuleDefinition<"incompleteBranch" | "incompleteIf" | "incompleteSwitch" | "unexpectedIf" | "unexpectedSwitch", [{
                            allowReturningBranches: boolean | "ifExhaustive";
                        }]>;
                        "no-expression-statements": RuleDefinition<"generic", [Readonly<{
                            ignoreCodePattern?: string | readonly string[];
                        }> & {
                            ignoreVoid: boolean;
                            ignoreSelfReturning: boolean;
                        }]>;
                        "no-let": RuleDefinition<"generic", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            allowInForLoopInit: boolean;
                            allowInFunctions: boolean;
                        }]>;
                        "no-loop-statements": RuleDefinition<"generic", [{}]>;
                        "no-mixed-types": RuleDefinition<"generic", [{
                            checkInterfaces: boolean;
                            checkTypeLiterals: boolean;
                        }]>;
                        "no-promise-reject": RuleDefinition<"generic", [{}]>;
                        "no-return-void": RuleDefinition<"generic", [{
                            allowNull: boolean;
                            allowUndefined: boolean;
                            ignoreInferredTypes: boolean;
                        }]>;
                        "no-this-expressions": RuleDefinition<"generic", [{}]>;
                        "no-throw-statements": RuleDefinition<"generic", [{
                            allowInAsyncFunctions: boolean;
                        }]>;
                        "no-try-statements": RuleDefinition<"catch" | "finally", [{
                            allowCatch: boolean;
                            allowFinally: boolean;
                        }]>;
                        "prefer-immutable-types": RuleDefinition<"returnType" | "parameter" | "variable" | "propertyImmutability" | "propertyModifier", [Readonly<{
                            ignoreClasses: boolean | "fieldsOnly";
                        }> & {
                            enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                            ignoreInferredTypes: boolean;
                            ignoreNamePattern?: string | string[];
                            ignoreTypePattern?: string | string[];
                        } & {
                            parameters?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            }>;
                            returnTypes?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            }>;
                            variables?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            } & {
                                ignoreInFunctions?: boolean;
                            }>;
                            fixer?: Partial<Record<"ReadonlyShallow" | "ReadonlyDeep" | "Immutable", {
                                pattern: string;
                                replace: string;
                            } | {
                                pattern: string;
                                replace: string;
                            }[] | undefined>>;
                            suggestions?: Partial<Record<"ReadonlyShallow" | "ReadonlyDeep" | "Immutable", {
                                pattern: string;
                                replace: string;
                            }[][] | undefined>>;
                        }]>;
                        "prefer-property-signatures": RuleDefinition<"generic", [{
                            ignoreIfReadonlyWrapped: boolean;
                        }]>;
                        "prefer-readonly-type": RuleDefinition<"type" | "array" | "property" | "implicit" | "tuple", [{
                            allowLocalMutation: boolean;
                            allowMutableReturnType: boolean;
                            checkImplicit: boolean;
                            ignoreCollections: boolean;
                            ignoreClass: boolean | "fieldsOnly";
                            ignoreInterface: boolean;
                            ignorePattern?: string | string[];
                        }]>;
                        "prefer-tacit": RuleDefinition<"generic", []>;
                        "readonly-type": RuleDefinition<"generic" | "keyword", ["generic" | "keyword"]>;
                        "type-declaration-immutability": RuleDefinition<"Less" | "AtMost" | "Exactly" | "AtLeast" | "More", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            rules: {
                                identifiers: string | string[];
                                immutability: import("is-immutable-type").Immutability | "Mutable" | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating";
                                comparator?: RuleEnforcementComparator | "Less" | "AtMost" | "Exactly" | "AtLeast" | "More";
                                fixer?: false | {
                                    pattern: string;
                                    replace: string;
                                } | {
                                    pattern: string;
                                    replace: string;
                                }[];
                            }[];
                            ignoreInterfaces: boolean;
                        }]>;
                    };
                };
            };
            rules: {
                [k: string]: "off";
            };
        };
        disableTypeChecked: {
            plugins: {
                functional: {
                    meta: {
                        readonly name: "eslint-plugin-functional";
                        readonly version: "0.0.0-development";
                    };
                    rules: {
                        "functional-parameters": RuleDefinition<"arguments" | "restParam" | "paramCountAtLeastOne" | "paramCountExactlyOne", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & Readonly<{
                            ignorePrefixSelector?: string | readonly string[];
                        }> & {
                            allowRestParameter: boolean;
                            allowArgumentsKeyword: boolean;
                            enforceParameterCount: false | ("atLeastOne" | "exactlyOne") | {
                                count: "atLeastOne" | "exactlyOne";
                                ignoreLambdaExpression: boolean;
                                ignoreIIFE: boolean;
                                ignoreGettersAndSetters: boolean;
                            };
                        }]>;
                        "immutable-data": RuleDefinition<"object" | "array" | "generic", [Readonly<{
                            ignoreAccessorPattern?: string | readonly string[];
                        }> & Readonly<{
                            ignoreClasses: boolean | "fieldsOnly";
                        }> & Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            ignoreImmediateMutation: boolean;
                            ignoreNonConstDeclarations: boolean | {
                                treatParametersAsConst: boolean;
                            };
                        }]>;
                        "no-classes": RuleDefinition<"generic", [{}]>;
                        "no-conditional-statements": RuleDefinition<"incompleteBranch" | "incompleteIf" | "incompleteSwitch" | "unexpectedIf" | "unexpectedSwitch", [{
                            allowReturningBranches: boolean | "ifExhaustive";
                        }]>;
                        "no-expression-statements": RuleDefinition<"generic", [Readonly<{
                            ignoreCodePattern?: string | readonly string[];
                        }> & {
                            ignoreVoid: boolean;
                            ignoreSelfReturning: boolean;
                        }]>;
                        "no-let": RuleDefinition<"generic", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            allowInForLoopInit: boolean;
                            allowInFunctions: boolean;
                        }]>;
                        "no-loop-statements": RuleDefinition<"generic", [{}]>;
                        "no-mixed-types": RuleDefinition<"generic", [{
                            checkInterfaces: boolean;
                            checkTypeLiterals: boolean;
                        }]>;
                        "no-promise-reject": RuleDefinition<"generic", [{}]>;
                        "no-return-void": RuleDefinition<"generic", [{
                            allowNull: boolean;
                            allowUndefined: boolean;
                            ignoreInferredTypes: boolean;
                        }]>;
                        "no-this-expressions": RuleDefinition<"generic", [{}]>;
                        "no-throw-statements": RuleDefinition<"generic", [{
                            allowInAsyncFunctions: boolean;
                        }]>;
                        "no-try-statements": RuleDefinition<"catch" | "finally", [{
                            allowCatch: boolean;
                            allowFinally: boolean;
                        }]>;
                        "prefer-immutable-types": RuleDefinition<"returnType" | "parameter" | "variable" | "propertyImmutability" | "propertyModifier", [Readonly<{
                            ignoreClasses: boolean | "fieldsOnly";
                        }> & {
                            enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                            ignoreInferredTypes: boolean;
                            ignoreNamePattern?: string | string[];
                            ignoreTypePattern?: string | string[];
                        } & {
                            parameters?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            }>;
                            returnTypes?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            }>;
                            variables?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            } & {
                                ignoreInFunctions?: boolean;
                            }>;
                            fixer?: Partial<Record<"ReadonlyShallow" | "ReadonlyDeep" | "Immutable", {
                                pattern: string;
                                replace: string;
                            } | {
                                pattern: string;
                                replace: string;
                            }[] | undefined>>;
                            suggestions?: Partial<Record<"ReadonlyShallow" | "ReadonlyDeep" | "Immutable", {
                                pattern: string;
                                replace: string;
                            }[][] | undefined>>;
                        }]>;
                        "prefer-property-signatures": RuleDefinition<"generic", [{
                            ignoreIfReadonlyWrapped: boolean;
                        }]>;
                        "prefer-readonly-type": RuleDefinition<"type" | "array" | "property" | "implicit" | "tuple", [{
                            allowLocalMutation: boolean;
                            allowMutableReturnType: boolean;
                            checkImplicit: boolean;
                            ignoreCollections: boolean;
                            ignoreClass: boolean | "fieldsOnly";
                            ignoreInterface: boolean;
                            ignorePattern?: string | string[];
                        }]>;
                        "prefer-tacit": RuleDefinition<"generic", []>;
                        "readonly-type": RuleDefinition<"generic" | "keyword", ["generic" | "keyword"]>;
                        "type-declaration-immutability": RuleDefinition<"Less" | "AtMost" | "Exactly" | "AtLeast" | "More", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            rules: {
                                identifiers: string | string[];
                                immutability: import("is-immutable-type").Immutability | "Mutable" | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating";
                                comparator?: RuleEnforcementComparator | "Less" | "AtMost" | "Exactly" | "AtLeast" | "More";
                                fixer?: false | {
                                    pattern: string;
                                    replace: string;
                                } | {
                                    pattern: string;
                                    replace: string;
                                }[];
                            }[];
                            ignoreInterfaces: boolean;
                        }]>;
                    };
                };
            };
            rules: {
                [k: string]: "off";
            };
        };
        externalVanillaRecommended: {
            plugins: {
                functional: {
                    meta: {
                        readonly name: "eslint-plugin-functional";
                        readonly version: "0.0.0-development";
                    };
                    rules: {
                        "functional-parameters": RuleDefinition<"arguments" | "restParam" | "paramCountAtLeastOne" | "paramCountExactlyOne", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & Readonly<{
                            ignorePrefixSelector?: string | readonly string[];
                        }> & {
                            allowRestParameter: boolean;
                            allowArgumentsKeyword: boolean;
                            enforceParameterCount: false | ("atLeastOne" | "exactlyOne") | {
                                count: "atLeastOne" | "exactlyOne";
                                ignoreLambdaExpression: boolean;
                                ignoreIIFE: boolean;
                                ignoreGettersAndSetters: boolean;
                            };
                        }]>;
                        "immutable-data": RuleDefinition<"object" | "array" | "generic", [Readonly<{
                            ignoreAccessorPattern?: string | readonly string[];
                        }> & Readonly<{
                            ignoreClasses: boolean | "fieldsOnly";
                        }> & Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            ignoreImmediateMutation: boolean;
                            ignoreNonConstDeclarations: boolean | {
                                treatParametersAsConst: boolean;
                            };
                        }]>;
                        "no-classes": RuleDefinition<"generic", [{}]>;
                        "no-conditional-statements": RuleDefinition<"incompleteBranch" | "incompleteIf" | "incompleteSwitch" | "unexpectedIf" | "unexpectedSwitch", [{
                            allowReturningBranches: boolean | "ifExhaustive";
                        }]>;
                        "no-expression-statements": RuleDefinition<"generic", [Readonly<{
                            ignoreCodePattern?: string | readonly string[];
                        }> & {
                            ignoreVoid: boolean;
                            ignoreSelfReturning: boolean;
                        }]>;
                        "no-let": RuleDefinition<"generic", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            allowInForLoopInit: boolean;
                            allowInFunctions: boolean;
                        }]>;
                        "no-loop-statements": RuleDefinition<"generic", [{}]>;
                        "no-mixed-types": RuleDefinition<"generic", [{
                            checkInterfaces: boolean;
                            checkTypeLiterals: boolean;
                        }]>;
                        "no-promise-reject": RuleDefinition<"generic", [{}]>;
                        "no-return-void": RuleDefinition<"generic", [{
                            allowNull: boolean;
                            allowUndefined: boolean;
                            ignoreInferredTypes: boolean;
                        }]>;
                        "no-this-expressions": RuleDefinition<"generic", [{}]>;
                        "no-throw-statements": RuleDefinition<"generic", [{
                            allowInAsyncFunctions: boolean;
                        }]>;
                        "no-try-statements": RuleDefinition<"catch" | "finally", [{
                            allowCatch: boolean;
                            allowFinally: boolean;
                        }]>;
                        "prefer-immutable-types": RuleDefinition<"returnType" | "parameter" | "variable" | "propertyImmutability" | "propertyModifier", [Readonly<{
                            ignoreClasses: boolean | "fieldsOnly";
                        }> & {
                            enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                            ignoreInferredTypes: boolean;
                            ignoreNamePattern?: string | string[];
                            ignoreTypePattern?: string | string[];
                        } & {
                            parameters?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            }>;
                            returnTypes?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            }>;
                            variables?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            } & {
                                ignoreInFunctions?: boolean;
                            }>;
                            fixer?: Partial<Record<"ReadonlyShallow" | "ReadonlyDeep" | "Immutable", {
                                pattern: string;
                                replace: string;
                            } | {
                                pattern: string;
                                replace: string;
                            }[] | undefined>>;
                            suggestions?: Partial<Record<"ReadonlyShallow" | "ReadonlyDeep" | "Immutable", {
                                pattern: string;
                                replace: string;
                            }[][] | undefined>>;
                        }]>;
                        "prefer-property-signatures": RuleDefinition<"generic", [{
                            ignoreIfReadonlyWrapped: boolean;
                        }]>;
                        "prefer-readonly-type": RuleDefinition<"type" | "array" | "property" | "implicit" | "tuple", [{
                            allowLocalMutation: boolean;
                            allowMutableReturnType: boolean;
                            checkImplicit: boolean;
                            ignoreCollections: boolean;
                            ignoreClass: boolean | "fieldsOnly";
                            ignoreInterface: boolean;
                            ignorePattern?: string | string[];
                        }]>;
                        "prefer-tacit": RuleDefinition<"generic", []>;
                        "readonly-type": RuleDefinition<"generic" | "keyword", ["generic" | "keyword"]>;
                        "type-declaration-immutability": RuleDefinition<"Less" | "AtMost" | "Exactly" | "AtLeast" | "More", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            rules: {
                                identifiers: string | string[];
                                immutability: import("is-immutable-type").Immutability | "Mutable" | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating";
                                comparator?: RuleEnforcementComparator | "Less" | "AtMost" | "Exactly" | "AtLeast" | "More";
                                fixer?: false | {
                                    pattern: string;
                                    replace: string;
                                } | {
                                    pattern: string;
                                    replace: string;
                                }[];
                            }[];
                            ignoreInterfaces: boolean;
                        }]>;
                    };
                };
            };
            rules: {
                "prefer-const": "error";
                "no-param-reassign": "error";
                "no-var": "error";
            };
        };
        externalTypescriptRecommended: {
            plugins: {
                functional: {
                    meta: {
                        readonly name: "eslint-plugin-functional";
                        readonly version: "0.0.0-development";
                    };
                    rules: {
                        "functional-parameters": RuleDefinition<"arguments" | "restParam" | "paramCountAtLeastOne" | "paramCountExactlyOne", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & Readonly<{
                            ignorePrefixSelector?: string | readonly string[];
                        }> & {
                            allowRestParameter: boolean;
                            allowArgumentsKeyword: boolean;
                            enforceParameterCount: false | ("atLeastOne" | "exactlyOne") | {
                                count: "atLeastOne" | "exactlyOne";
                                ignoreLambdaExpression: boolean;
                                ignoreIIFE: boolean;
                                ignoreGettersAndSetters: boolean;
                            };
                        }]>;
                        "immutable-data": RuleDefinition<"object" | "array" | "generic", [Readonly<{
                            ignoreAccessorPattern?: string | readonly string[];
                        }> & Readonly<{
                            ignoreClasses: boolean | "fieldsOnly";
                        }> & Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            ignoreImmediateMutation: boolean;
                            ignoreNonConstDeclarations: boolean | {
                                treatParametersAsConst: boolean;
                            };
                        }]>;
                        "no-classes": RuleDefinition<"generic", [{}]>;
                        "no-conditional-statements": RuleDefinition<"incompleteBranch" | "incompleteIf" | "incompleteSwitch" | "unexpectedIf" | "unexpectedSwitch", [{
                            allowReturningBranches: boolean | "ifExhaustive";
                        }]>;
                        "no-expression-statements": RuleDefinition<"generic", [Readonly<{
                            ignoreCodePattern?: string | readonly string[];
                        }> & {
                            ignoreVoid: boolean;
                            ignoreSelfReturning: boolean;
                        }]>;
                        "no-let": RuleDefinition<"generic", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            allowInForLoopInit: boolean;
                            allowInFunctions: boolean;
                        }]>;
                        "no-loop-statements": RuleDefinition<"generic", [{}]>;
                        "no-mixed-types": RuleDefinition<"generic", [{
                            checkInterfaces: boolean;
                            checkTypeLiterals: boolean;
                        }]>;
                        "no-promise-reject": RuleDefinition<"generic", [{}]>;
                        "no-return-void": RuleDefinition<"generic", [{
                            allowNull: boolean;
                            allowUndefined: boolean;
                            ignoreInferredTypes: boolean;
                        }]>;
                        "no-this-expressions": RuleDefinition<"generic", [{}]>;
                        "no-throw-statements": RuleDefinition<"generic", [{
                            allowInAsyncFunctions: boolean;
                        }]>;
                        "no-try-statements": RuleDefinition<"catch" | "finally", [{
                            allowCatch: boolean;
                            allowFinally: boolean;
                        }]>;
                        "prefer-immutable-types": RuleDefinition<"returnType" | "parameter" | "variable" | "propertyImmutability" | "propertyModifier", [Readonly<{
                            ignoreClasses: boolean | "fieldsOnly";
                        }> & {
                            enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                            ignoreInferredTypes: boolean;
                            ignoreNamePattern?: string | string[];
                            ignoreTypePattern?: string | string[];
                        } & {
                            parameters?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            }>;
                            returnTypes?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            }>;
                            variables?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            } & {
                                ignoreInFunctions?: boolean;
                            }>;
                            fixer?: Partial<Record<"ReadonlyShallow" | "ReadonlyDeep" | "Immutable", {
                                pattern: string;
                                replace: string;
                            } | {
                                pattern: string;
                                replace: string;
                            }[] | undefined>>;
                            suggestions?: Partial<Record<"ReadonlyShallow" | "ReadonlyDeep" | "Immutable", {
                                pattern: string;
                                replace: string;
                            }[][] | undefined>>;
                        }]>;
                        "prefer-property-signatures": RuleDefinition<"generic", [{
                            ignoreIfReadonlyWrapped: boolean;
                        }]>;
                        "prefer-readonly-type": RuleDefinition<"type" | "array" | "property" | "implicit" | "tuple", [{
                            allowLocalMutation: boolean;
                            allowMutableReturnType: boolean;
                            checkImplicit: boolean;
                            ignoreCollections: boolean;
                            ignoreClass: boolean | "fieldsOnly";
                            ignoreInterface: boolean;
                            ignorePattern?: string | string[];
                        }]>;
                        "prefer-tacit": RuleDefinition<"generic", []>;
                        "readonly-type": RuleDefinition<"generic" | "keyword", ["generic" | "keyword"]>;
                        "type-declaration-immutability": RuleDefinition<"Less" | "AtMost" | "Exactly" | "AtLeast" | "More", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            rules: {
                                identifiers: string | string[];
                                immutability: import("is-immutable-type").Immutability | "Mutable" | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating";
                                comparator?: RuleEnforcementComparator | "Less" | "AtMost" | "Exactly" | "AtLeast" | "More";
                                fixer?: false | {
                                    pattern: string;
                                    replace: string;
                                } | {
                                    pattern: string;
                                    replace: string;
                                }[];
                            }[];
                            ignoreInterfaces: boolean;
                        }]>;
                    };
                };
            };
            rules: {
                "@typescript-eslint/prefer-readonly": "error";
                "@typescript-eslint/switch-exhaustiveness-check": "error";
                "prefer-const": "error";
                "no-param-reassign": "error";
                "no-var": "error";
            };
        };
        currying: {
            plugins: {
                functional: {
                    meta: {
                        readonly name: "eslint-plugin-functional";
                        readonly version: "0.0.0-development";
                    };
                    rules: {
                        "functional-parameters": RuleDefinition<"arguments" | "restParam" | "paramCountAtLeastOne" | "paramCountExactlyOne", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & Readonly<{
                            ignorePrefixSelector?: string | readonly string[];
                        }> & {
                            allowRestParameter: boolean;
                            allowArgumentsKeyword: boolean;
                            enforceParameterCount: false | ("atLeastOne" | "exactlyOne") | {
                                count: "atLeastOne" | "exactlyOne";
                                ignoreLambdaExpression: boolean;
                                ignoreIIFE: boolean;
                                ignoreGettersAndSetters: boolean;
                            };
                        }]>;
                        "immutable-data": RuleDefinition<"object" | "array" | "generic", [Readonly<{
                            ignoreAccessorPattern?: string | readonly string[];
                        }> & Readonly<{
                            ignoreClasses: boolean | "fieldsOnly";
                        }> & Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            ignoreImmediateMutation: boolean;
                            ignoreNonConstDeclarations: boolean | {
                                treatParametersAsConst: boolean;
                            };
                        }]>;
                        "no-classes": RuleDefinition<"generic", [{}]>;
                        "no-conditional-statements": RuleDefinition<"incompleteBranch" | "incompleteIf" | "incompleteSwitch" | "unexpectedIf" | "unexpectedSwitch", [{
                            allowReturningBranches: boolean | "ifExhaustive";
                        }]>;
                        "no-expression-statements": RuleDefinition<"generic", [Readonly<{
                            ignoreCodePattern?: string | readonly string[];
                        }> & {
                            ignoreVoid: boolean;
                            ignoreSelfReturning: boolean;
                        }]>;
                        "no-let": RuleDefinition<"generic", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            allowInForLoopInit: boolean;
                            allowInFunctions: boolean;
                        }]>;
                        "no-loop-statements": RuleDefinition<"generic", [{}]>;
                        "no-mixed-types": RuleDefinition<"generic", [{
                            checkInterfaces: boolean;
                            checkTypeLiterals: boolean;
                        }]>;
                        "no-promise-reject": RuleDefinition<"generic", [{}]>;
                        "no-return-void": RuleDefinition<"generic", [{
                            allowNull: boolean;
                            allowUndefined: boolean;
                            ignoreInferredTypes: boolean;
                        }]>;
                        "no-this-expressions": RuleDefinition<"generic", [{}]>;
                        "no-throw-statements": RuleDefinition<"generic", [{
                            allowInAsyncFunctions: boolean;
                        }]>;
                        "no-try-statements": RuleDefinition<"catch" | "finally", [{
                            allowCatch: boolean;
                            allowFinally: boolean;
                        }]>;
                        "prefer-immutable-types": RuleDefinition<"returnType" | "parameter" | "variable" | "propertyImmutability" | "propertyModifier", [Readonly<{
                            ignoreClasses: boolean | "fieldsOnly";
                        }> & {
                            enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                            ignoreInferredTypes: boolean;
                            ignoreNamePattern?: string | string[];
                            ignoreTypePattern?: string | string[];
                        } & {
                            parameters?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            }>;
                            returnTypes?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            }>;
                            variables?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            } & {
                                ignoreInFunctions?: boolean;
                            }>;
                            fixer?: Partial<Record<"ReadonlyShallow" | "ReadonlyDeep" | "Immutable", {
                                pattern: string;
                                replace: string;
                            } | {
                                pattern: string;
                                replace: string;
                            }[] | undefined>>;
                            suggestions?: Partial<Record<"ReadonlyShallow" | "ReadonlyDeep" | "Immutable", {
                                pattern: string;
                                replace: string;
                            }[][] | undefined>>;
                        }]>;
                        "prefer-property-signatures": RuleDefinition<"generic", [{
                            ignoreIfReadonlyWrapped: boolean;
                        }]>;
                        "prefer-readonly-type": RuleDefinition<"type" | "array" | "property" | "implicit" | "tuple", [{
                            allowLocalMutation: boolean;
                            allowMutableReturnType: boolean;
                            checkImplicit: boolean;
                            ignoreCollections: boolean;
                            ignoreClass: boolean | "fieldsOnly";
                            ignoreInterface: boolean;
                            ignorePattern?: string | string[];
                        }]>;
                        "prefer-tacit": RuleDefinition<"generic", []>;
                        "readonly-type": RuleDefinition<"generic" | "keyword", ["generic" | "keyword"]>;
                        "type-declaration-immutability": RuleDefinition<"Less" | "AtMost" | "Exactly" | "AtLeast" | "More", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            rules: {
                                identifiers: string | string[];
                                immutability: import("is-immutable-type").Immutability | "Mutable" | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating";
                                comparator?: RuleEnforcementComparator | "Less" | "AtMost" | "Exactly" | "AtLeast" | "More";
                                fixer?: false | {
                                    pattern: string;
                                    replace: string;
                                } | {
                                    pattern: string;
                                    replace: string;
                                }[];
                            }[];
                            ignoreInterfaces: boolean;
                        }]>;
                    };
                };
            };
            rules: {
                [k: string]: "error" | "warn";
            };
        };
        noExceptions: {
            plugins: {
                functional: {
                    meta: {
                        readonly name: "eslint-plugin-functional";
                        readonly version: "0.0.0-development";
                    };
                    rules: {
                        "functional-parameters": RuleDefinition<"arguments" | "restParam" | "paramCountAtLeastOne" | "paramCountExactlyOne", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & Readonly<{
                            ignorePrefixSelector?: string | readonly string[];
                        }> & {
                            allowRestParameter: boolean;
                            allowArgumentsKeyword: boolean;
                            enforceParameterCount: false | ("atLeastOne" | "exactlyOne") | {
                                count: "atLeastOne" | "exactlyOne";
                                ignoreLambdaExpression: boolean;
                                ignoreIIFE: boolean;
                                ignoreGettersAndSetters: boolean;
                            };
                        }]>;
                        "immutable-data": RuleDefinition<"object" | "array" | "generic", [Readonly<{
                            ignoreAccessorPattern?: string | readonly string[];
                        }> & Readonly<{
                            ignoreClasses: boolean | "fieldsOnly";
                        }> & Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            ignoreImmediateMutation: boolean;
                            ignoreNonConstDeclarations: boolean | {
                                treatParametersAsConst: boolean;
                            };
                        }]>;
                        "no-classes": RuleDefinition<"generic", [{}]>;
                        "no-conditional-statements": RuleDefinition<"incompleteBranch" | "incompleteIf" | "incompleteSwitch" | "unexpectedIf" | "unexpectedSwitch", [{
                            allowReturningBranches: boolean | "ifExhaustive";
                        }]>;
                        "no-expression-statements": RuleDefinition<"generic", [Readonly<{
                            ignoreCodePattern?: string | readonly string[];
                        }> & {
                            ignoreVoid: boolean;
                            ignoreSelfReturning: boolean;
                        }]>;
                        "no-let": RuleDefinition<"generic", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            allowInForLoopInit: boolean;
                            allowInFunctions: boolean;
                        }]>;
                        "no-loop-statements": RuleDefinition<"generic", [{}]>;
                        "no-mixed-types": RuleDefinition<"generic", [{
                            checkInterfaces: boolean;
                            checkTypeLiterals: boolean;
                        }]>;
                        "no-promise-reject": RuleDefinition<"generic", [{}]>;
                        "no-return-void": RuleDefinition<"generic", [{
                            allowNull: boolean;
                            allowUndefined: boolean;
                            ignoreInferredTypes: boolean;
                        }]>;
                        "no-this-expressions": RuleDefinition<"generic", [{}]>;
                        "no-throw-statements": RuleDefinition<"generic", [{
                            allowInAsyncFunctions: boolean;
                        }]>;
                        "no-try-statements": RuleDefinition<"catch" | "finally", [{
                            allowCatch: boolean;
                            allowFinally: boolean;
                        }]>;
                        "prefer-immutable-types": RuleDefinition<"returnType" | "parameter" | "variable" | "propertyImmutability" | "propertyModifier", [Readonly<{
                            ignoreClasses: boolean | "fieldsOnly";
                        }> & {
                            enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                            ignoreInferredTypes: boolean;
                            ignoreNamePattern?: string | string[];
                            ignoreTypePattern?: string | string[];
                        } & {
                            parameters?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            }>;
                            returnTypes?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            }>;
                            variables?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            } & {
                                ignoreInFunctions?: boolean;
                            }>;
                            fixer?: Partial<Record<"ReadonlyShallow" | "ReadonlyDeep" | "Immutable", {
                                pattern: string;
                                replace: string;
                            } | {
                                pattern: string;
                                replace: string;
                            }[] | undefined>>;
                            suggestions?: Partial<Record<"ReadonlyShallow" | "ReadonlyDeep" | "Immutable", {
                                pattern: string;
                                replace: string;
                            }[][] | undefined>>;
                        }]>;
                        "prefer-property-signatures": RuleDefinition<"generic", [{
                            ignoreIfReadonlyWrapped: boolean;
                        }]>;
                        "prefer-readonly-type": RuleDefinition<"type" | "array" | "property" | "implicit" | "tuple", [{
                            allowLocalMutation: boolean;
                            allowMutableReturnType: boolean;
                            checkImplicit: boolean;
                            ignoreCollections: boolean;
                            ignoreClass: boolean | "fieldsOnly";
                            ignoreInterface: boolean;
                            ignorePattern?: string | string[];
                        }]>;
                        "prefer-tacit": RuleDefinition<"generic", []>;
                        "readonly-type": RuleDefinition<"generic" | "keyword", ["generic" | "keyword"]>;
                        "type-declaration-immutability": RuleDefinition<"Less" | "AtMost" | "Exactly" | "AtLeast" | "More", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            rules: {
                                identifiers: string | string[];
                                immutability: import("is-immutable-type").Immutability | "Mutable" | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating";
                                comparator?: RuleEnforcementComparator | "Less" | "AtMost" | "Exactly" | "AtLeast" | "More";
                                fixer?: false | {
                                    pattern: string;
                                    replace: string;
                                } | {
                                    pattern: string;
                                    replace: string;
                                }[];
                            }[];
                            ignoreInterfaces: boolean;
                        }]>;
                    };
                };
            };
            rules: {
                [k: string]: "error" | "warn";
            };
        };
        noMutations: {
            plugins: {
                functional: {
                    meta: {
                        readonly name: "eslint-plugin-functional";
                        readonly version: "0.0.0-development";
                    };
                    rules: {
                        "functional-parameters": RuleDefinition<"arguments" | "restParam" | "paramCountAtLeastOne" | "paramCountExactlyOne", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & Readonly<{
                            ignorePrefixSelector?: string | readonly string[];
                        }> & {
                            allowRestParameter: boolean;
                            allowArgumentsKeyword: boolean;
                            enforceParameterCount: false | ("atLeastOne" | "exactlyOne") | {
                                count: "atLeastOne" | "exactlyOne";
                                ignoreLambdaExpression: boolean;
                                ignoreIIFE: boolean;
                                ignoreGettersAndSetters: boolean;
                            };
                        }]>;
                        "immutable-data": RuleDefinition<"object" | "array" | "generic", [Readonly<{
                            ignoreAccessorPattern?: string | readonly string[];
                        }> & Readonly<{
                            ignoreClasses: boolean | "fieldsOnly";
                        }> & Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            ignoreImmediateMutation: boolean;
                            ignoreNonConstDeclarations: boolean | {
                                treatParametersAsConst: boolean;
                            };
                        }]>;
                        "no-classes": RuleDefinition<"generic", [{}]>;
                        "no-conditional-statements": RuleDefinition<"incompleteBranch" | "incompleteIf" | "incompleteSwitch" | "unexpectedIf" | "unexpectedSwitch", [{
                            allowReturningBranches: boolean | "ifExhaustive";
                        }]>;
                        "no-expression-statements": RuleDefinition<"generic", [Readonly<{
                            ignoreCodePattern?: string | readonly string[];
                        }> & {
                            ignoreVoid: boolean;
                            ignoreSelfReturning: boolean;
                        }]>;
                        "no-let": RuleDefinition<"generic", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            allowInForLoopInit: boolean;
                            allowInFunctions: boolean;
                        }]>;
                        "no-loop-statements": RuleDefinition<"generic", [{}]>;
                        "no-mixed-types": RuleDefinition<"generic", [{
                            checkInterfaces: boolean;
                            checkTypeLiterals: boolean;
                        }]>;
                        "no-promise-reject": RuleDefinition<"generic", [{}]>;
                        "no-return-void": RuleDefinition<"generic", [{
                            allowNull: boolean;
                            allowUndefined: boolean;
                            ignoreInferredTypes: boolean;
                        }]>;
                        "no-this-expressions": RuleDefinition<"generic", [{}]>;
                        "no-throw-statements": RuleDefinition<"generic", [{
                            allowInAsyncFunctions: boolean;
                        }]>;
                        "no-try-statements": RuleDefinition<"catch" | "finally", [{
                            allowCatch: boolean;
                            allowFinally: boolean;
                        }]>;
                        "prefer-immutable-types": RuleDefinition<"returnType" | "parameter" | "variable" | "propertyImmutability" | "propertyModifier", [Readonly<{
                            ignoreClasses: boolean | "fieldsOnly";
                        }> & {
                            enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                            ignoreInferredTypes: boolean;
                            ignoreNamePattern?: string | string[];
                            ignoreTypePattern?: string | string[];
                        } & {
                            parameters?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            }>;
                            returnTypes?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            }>;
                            variables?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            } & {
                                ignoreInFunctions?: boolean;
                            }>;
                            fixer?: Partial<Record<"ReadonlyShallow" | "ReadonlyDeep" | "Immutable", {
                                pattern: string;
                                replace: string;
                            } | {
                                pattern: string;
                                replace: string;
                            }[] | undefined>>;
                            suggestions?: Partial<Record<"ReadonlyShallow" | "ReadonlyDeep" | "Immutable", {
                                pattern: string;
                                replace: string;
                            }[][] | undefined>>;
                        }]>;
                        "prefer-property-signatures": RuleDefinition<"generic", [{
                            ignoreIfReadonlyWrapped: boolean;
                        }]>;
                        "prefer-readonly-type": RuleDefinition<"type" | "array" | "property" | "implicit" | "tuple", [{
                            allowLocalMutation: boolean;
                            allowMutableReturnType: boolean;
                            checkImplicit: boolean;
                            ignoreCollections: boolean;
                            ignoreClass: boolean | "fieldsOnly";
                            ignoreInterface: boolean;
                            ignorePattern?: string | string[];
                        }]>;
                        "prefer-tacit": RuleDefinition<"generic", []>;
                        "readonly-type": RuleDefinition<"generic" | "keyword", ["generic" | "keyword"]>;
                        "type-declaration-immutability": RuleDefinition<"Less" | "AtMost" | "Exactly" | "AtLeast" | "More", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            rules: {
                                identifiers: string | string[];
                                immutability: import("is-immutable-type").Immutability | "Mutable" | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating";
                                comparator?: RuleEnforcementComparator | "Less" | "AtMost" | "Exactly" | "AtLeast" | "More";
                                fixer?: false | {
                                    pattern: string;
                                    replace: string;
                                } | {
                                    pattern: string;
                                    replace: string;
                                }[];
                            }[];
                            ignoreInterfaces: boolean;
                        }]>;
                    };
                };
            };
            rules: {
                [k: string]: "error" | "warn";
            };
        };
        noOtherParadigms: {
            plugins: {
                functional: {
                    meta: {
                        readonly name: "eslint-plugin-functional";
                        readonly version: "0.0.0-development";
                    };
                    rules: {
                        "functional-parameters": RuleDefinition<"arguments" | "restParam" | "paramCountAtLeastOne" | "paramCountExactlyOne", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & Readonly<{
                            ignorePrefixSelector?: string | readonly string[];
                        }> & {
                            allowRestParameter: boolean;
                            allowArgumentsKeyword: boolean;
                            enforceParameterCount: false | ("atLeastOne" | "exactlyOne") | {
                                count: "atLeastOne" | "exactlyOne";
                                ignoreLambdaExpression: boolean;
                                ignoreIIFE: boolean;
                                ignoreGettersAndSetters: boolean;
                            };
                        }]>;
                        "immutable-data": RuleDefinition<"object" | "array" | "generic", [Readonly<{
                            ignoreAccessorPattern?: string | readonly string[];
                        }> & Readonly<{
                            ignoreClasses: boolean | "fieldsOnly";
                        }> & Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            ignoreImmediateMutation: boolean;
                            ignoreNonConstDeclarations: boolean | {
                                treatParametersAsConst: boolean;
                            };
                        }]>;
                        "no-classes": RuleDefinition<"generic", [{}]>;
                        "no-conditional-statements": RuleDefinition<"incompleteBranch" | "incompleteIf" | "incompleteSwitch" | "unexpectedIf" | "unexpectedSwitch", [{
                            allowReturningBranches: boolean | "ifExhaustive";
                        }]>;
                        "no-expression-statements": RuleDefinition<"generic", [Readonly<{
                            ignoreCodePattern?: string | readonly string[];
                        }> & {
                            ignoreVoid: boolean;
                            ignoreSelfReturning: boolean;
                        }]>;
                        "no-let": RuleDefinition<"generic", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            allowInForLoopInit: boolean;
                            allowInFunctions: boolean;
                        }]>;
                        "no-loop-statements": RuleDefinition<"generic", [{}]>;
                        "no-mixed-types": RuleDefinition<"generic", [{
                            checkInterfaces: boolean;
                            checkTypeLiterals: boolean;
                        }]>;
                        "no-promise-reject": RuleDefinition<"generic", [{}]>;
                        "no-return-void": RuleDefinition<"generic", [{
                            allowNull: boolean;
                            allowUndefined: boolean;
                            ignoreInferredTypes: boolean;
                        }]>;
                        "no-this-expressions": RuleDefinition<"generic", [{}]>;
                        "no-throw-statements": RuleDefinition<"generic", [{
                            allowInAsyncFunctions: boolean;
                        }]>;
                        "no-try-statements": RuleDefinition<"catch" | "finally", [{
                            allowCatch: boolean;
                            allowFinally: boolean;
                        }]>;
                        "prefer-immutable-types": RuleDefinition<"returnType" | "parameter" | "variable" | "propertyImmutability" | "propertyModifier", [Readonly<{
                            ignoreClasses: boolean | "fieldsOnly";
                        }> & {
                            enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                            ignoreInferredTypes: boolean;
                            ignoreNamePattern?: string | string[];
                            ignoreTypePattern?: string | string[];
                        } & {
                            parameters?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            }>;
                            returnTypes?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            }>;
                            variables?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            } & {
                                ignoreInFunctions?: boolean;
                            }>;
                            fixer?: Partial<Record<"ReadonlyShallow" | "ReadonlyDeep" | "Immutable", {
                                pattern: string;
                                replace: string;
                            } | {
                                pattern: string;
                                replace: string;
                            }[] | undefined>>;
                            suggestions?: Partial<Record<"ReadonlyShallow" | "ReadonlyDeep" | "Immutable", {
                                pattern: string;
                                replace: string;
                            }[][] | undefined>>;
                        }]>;
                        "prefer-property-signatures": RuleDefinition<"generic", [{
                            ignoreIfReadonlyWrapped: boolean;
                        }]>;
                        "prefer-readonly-type": RuleDefinition<"type" | "array" | "property" | "implicit" | "tuple", [{
                            allowLocalMutation: boolean;
                            allowMutableReturnType: boolean;
                            checkImplicit: boolean;
                            ignoreCollections: boolean;
                            ignoreClass: boolean | "fieldsOnly";
                            ignoreInterface: boolean;
                            ignorePattern?: string | string[];
                        }]>;
                        "prefer-tacit": RuleDefinition<"generic", []>;
                        "readonly-type": RuleDefinition<"generic" | "keyword", ["generic" | "keyword"]>;
                        "type-declaration-immutability": RuleDefinition<"Less" | "AtMost" | "Exactly" | "AtLeast" | "More", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            rules: {
                                identifiers: string | string[];
                                immutability: import("is-immutable-type").Immutability | "Mutable" | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating";
                                comparator?: RuleEnforcementComparator | "Less" | "AtMost" | "Exactly" | "AtLeast" | "More";
                                fixer?: false | {
                                    pattern: string;
                                    replace: string;
                                } | {
                                    pattern: string;
                                    replace: string;
                                }[];
                            }[];
                            ignoreInterfaces: boolean;
                        }]>;
                    };
                };
            };
            rules: {
                [k: string]: "error" | "warn";
            };
        };
        noStatements: {
            plugins: {
                functional: {
                    meta: {
                        readonly name: "eslint-plugin-functional";
                        readonly version: "0.0.0-development";
                    };
                    rules: {
                        "functional-parameters": RuleDefinition<"arguments" | "restParam" | "paramCountAtLeastOne" | "paramCountExactlyOne", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & Readonly<{
                            ignorePrefixSelector?: string | readonly string[];
                        }> & {
                            allowRestParameter: boolean;
                            allowArgumentsKeyword: boolean;
                            enforceParameterCount: false | ("atLeastOne" | "exactlyOne") | {
                                count: "atLeastOne" | "exactlyOne";
                                ignoreLambdaExpression: boolean;
                                ignoreIIFE: boolean;
                                ignoreGettersAndSetters: boolean;
                            };
                        }]>;
                        "immutable-data": RuleDefinition<"object" | "array" | "generic", [Readonly<{
                            ignoreAccessorPattern?: string | readonly string[];
                        }> & Readonly<{
                            ignoreClasses: boolean | "fieldsOnly";
                        }> & Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            ignoreImmediateMutation: boolean;
                            ignoreNonConstDeclarations: boolean | {
                                treatParametersAsConst: boolean;
                            };
                        }]>;
                        "no-classes": RuleDefinition<"generic", [{}]>;
                        "no-conditional-statements": RuleDefinition<"incompleteBranch" | "incompleteIf" | "incompleteSwitch" | "unexpectedIf" | "unexpectedSwitch", [{
                            allowReturningBranches: boolean | "ifExhaustive";
                        }]>;
                        "no-expression-statements": RuleDefinition<"generic", [Readonly<{
                            ignoreCodePattern?: string | readonly string[];
                        }> & {
                            ignoreVoid: boolean;
                            ignoreSelfReturning: boolean;
                        }]>;
                        "no-let": RuleDefinition<"generic", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            allowInForLoopInit: boolean;
                            allowInFunctions: boolean;
                        }]>;
                        "no-loop-statements": RuleDefinition<"generic", [{}]>;
                        "no-mixed-types": RuleDefinition<"generic", [{
                            checkInterfaces: boolean;
                            checkTypeLiterals: boolean;
                        }]>;
                        "no-promise-reject": RuleDefinition<"generic", [{}]>;
                        "no-return-void": RuleDefinition<"generic", [{
                            allowNull: boolean;
                            allowUndefined: boolean;
                            ignoreInferredTypes: boolean;
                        }]>;
                        "no-this-expressions": RuleDefinition<"generic", [{}]>;
                        "no-throw-statements": RuleDefinition<"generic", [{
                            allowInAsyncFunctions: boolean;
                        }]>;
                        "no-try-statements": RuleDefinition<"catch" | "finally", [{
                            allowCatch: boolean;
                            allowFinally: boolean;
                        }]>;
                        "prefer-immutable-types": RuleDefinition<"returnType" | "parameter" | "variable" | "propertyImmutability" | "propertyModifier", [Readonly<{
                            ignoreClasses: boolean | "fieldsOnly";
                        }> & {
                            enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                            ignoreInferredTypes: boolean;
                            ignoreNamePattern?: string | string[];
                            ignoreTypePattern?: string | string[];
                        } & {
                            parameters?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            }>;
                            returnTypes?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            }>;
                            variables?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            } & {
                                ignoreInFunctions?: boolean;
                            }>;
                            fixer?: Partial<Record<"ReadonlyShallow" | "ReadonlyDeep" | "Immutable", {
                                pattern: string;
                                replace: string;
                            } | {
                                pattern: string;
                                replace: string;
                            }[] | undefined>>;
                            suggestions?: Partial<Record<"ReadonlyShallow" | "ReadonlyDeep" | "Immutable", {
                                pattern: string;
                                replace: string;
                            }[][] | undefined>>;
                        }]>;
                        "prefer-property-signatures": RuleDefinition<"generic", [{
                            ignoreIfReadonlyWrapped: boolean;
                        }]>;
                        "prefer-readonly-type": RuleDefinition<"type" | "array" | "property" | "implicit" | "tuple", [{
                            allowLocalMutation: boolean;
                            allowMutableReturnType: boolean;
                            checkImplicit: boolean;
                            ignoreCollections: boolean;
                            ignoreClass: boolean | "fieldsOnly";
                            ignoreInterface: boolean;
                            ignorePattern?: string | string[];
                        }]>;
                        "prefer-tacit": RuleDefinition<"generic", []>;
                        "readonly-type": RuleDefinition<"generic" | "keyword", ["generic" | "keyword"]>;
                        "type-declaration-immutability": RuleDefinition<"Less" | "AtMost" | "Exactly" | "AtLeast" | "More", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            rules: {
                                identifiers: string | string[];
                                immutability: import("is-immutable-type").Immutability | "Mutable" | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating";
                                comparator?: RuleEnforcementComparator | "Less" | "AtMost" | "Exactly" | "AtLeast" | "More";
                                fixer?: false | {
                                    pattern: string;
                                    replace: string;
                                } | {
                                    pattern: string;
                                    replace: string;
                                }[];
                            }[];
                            ignoreInterfaces: boolean;
                        }]>;
                    };
                };
            };
            rules: {
                [k: string]: "error" | "warn";
            };
        };
        stylistic: {
            plugins: {
                functional: {
                    meta: {
                        readonly name: "eslint-plugin-functional";
                        readonly version: "0.0.0-development";
                    };
                    rules: {
                        "functional-parameters": RuleDefinition<"arguments" | "restParam" | "paramCountAtLeastOne" | "paramCountExactlyOne", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & Readonly<{
                            ignorePrefixSelector?: string | readonly string[];
                        }> & {
                            allowRestParameter: boolean;
                            allowArgumentsKeyword: boolean;
                            enforceParameterCount: false | ("atLeastOne" | "exactlyOne") | {
                                count: "atLeastOne" | "exactlyOne";
                                ignoreLambdaExpression: boolean;
                                ignoreIIFE: boolean;
                                ignoreGettersAndSetters: boolean;
                            };
                        }]>;
                        "immutable-data": RuleDefinition<"object" | "array" | "generic", [Readonly<{
                            ignoreAccessorPattern?: string | readonly string[];
                        }> & Readonly<{
                            ignoreClasses: boolean | "fieldsOnly";
                        }> & Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            ignoreImmediateMutation: boolean;
                            ignoreNonConstDeclarations: boolean | {
                                treatParametersAsConst: boolean;
                            };
                        }]>;
                        "no-classes": RuleDefinition<"generic", [{}]>;
                        "no-conditional-statements": RuleDefinition<"incompleteBranch" | "incompleteIf" | "incompleteSwitch" | "unexpectedIf" | "unexpectedSwitch", [{
                            allowReturningBranches: boolean | "ifExhaustive";
                        }]>;
                        "no-expression-statements": RuleDefinition<"generic", [Readonly<{
                            ignoreCodePattern?: string | readonly string[];
                        }> & {
                            ignoreVoid: boolean;
                            ignoreSelfReturning: boolean;
                        }]>;
                        "no-let": RuleDefinition<"generic", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            allowInForLoopInit: boolean;
                            allowInFunctions: boolean;
                        }]>;
                        "no-loop-statements": RuleDefinition<"generic", [{}]>;
                        "no-mixed-types": RuleDefinition<"generic", [{
                            checkInterfaces: boolean;
                            checkTypeLiterals: boolean;
                        }]>;
                        "no-promise-reject": RuleDefinition<"generic", [{}]>;
                        "no-return-void": RuleDefinition<"generic", [{
                            allowNull: boolean;
                            allowUndefined: boolean;
                            ignoreInferredTypes: boolean;
                        }]>;
                        "no-this-expressions": RuleDefinition<"generic", [{}]>;
                        "no-throw-statements": RuleDefinition<"generic", [{
                            allowInAsyncFunctions: boolean;
                        }]>;
                        "no-try-statements": RuleDefinition<"catch" | "finally", [{
                            allowCatch: boolean;
                            allowFinally: boolean;
                        }]>;
                        "prefer-immutable-types": RuleDefinition<"returnType" | "parameter" | "variable" | "propertyImmutability" | "propertyModifier", [Readonly<{
                            ignoreClasses: boolean | "fieldsOnly";
                        }> & {
                            enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                            ignoreInferredTypes: boolean;
                            ignoreNamePattern?: string | string[];
                            ignoreTypePattern?: string | string[];
                        } & {
                            parameters?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            }>;
                            returnTypes?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            }>;
                            variables?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                                ignoreClasses: boolean | "fieldsOnly";
                            }> & {
                                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                                ignoreInferredTypes: boolean;
                                ignoreNamePattern?: string | string[];
                                ignoreTypePattern?: string | string[];
                            } & {
                                ignoreInFunctions?: boolean;
                            }>;
                            fixer?: Partial<Record<"ReadonlyShallow" | "ReadonlyDeep" | "Immutable", {
                                pattern: string;
                                replace: string;
                            } | {
                                pattern: string;
                                replace: string;
                            }[] | undefined>>;
                            suggestions?: Partial<Record<"ReadonlyShallow" | "ReadonlyDeep" | "Immutable", {
                                pattern: string;
                                replace: string;
                            }[][] | undefined>>;
                        }]>;
                        "prefer-property-signatures": RuleDefinition<"generic", [{
                            ignoreIfReadonlyWrapped: boolean;
                        }]>;
                        "prefer-readonly-type": RuleDefinition<"type" | "array" | "property" | "implicit" | "tuple", [{
                            allowLocalMutation: boolean;
                            allowMutableReturnType: boolean;
                            checkImplicit: boolean;
                            ignoreCollections: boolean;
                            ignoreClass: boolean | "fieldsOnly";
                            ignoreInterface: boolean;
                            ignorePattern?: string | string[];
                        }]>;
                        "prefer-tacit": RuleDefinition<"generic", []>;
                        "readonly-type": RuleDefinition<"generic" | "keyword", ["generic" | "keyword"]>;
                        "type-declaration-immutability": RuleDefinition<"Less" | "AtMost" | "Exactly" | "AtLeast" | "More", [Readonly<{
                            ignoreIdentifierPattern?: string | readonly string[];
                        }> & {
                            rules: {
                                identifiers: string | string[];
                                immutability: import("is-immutable-type").Immutability | "Mutable" | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating";
                                comparator?: RuleEnforcementComparator | "Less" | "AtMost" | "Exactly" | "AtLeast" | "More";
                                fixer?: false | {
                                    pattern: string;
                                    replace: string;
                                } | {
                                    pattern: string;
                                    replace: string;
                                }[];
                            }[];
                            ignoreInterfaces: boolean;
                        }]>;
                    };
                };
            };
            rules: {
                [k: string]: "error" | "warn";
            };
        };
    };
    readonly meta: {
        readonly name: "eslint-plugin-functional";
        readonly version: "0.0.0-development";
    };
    readonly rules: {
        "functional-parameters": RuleDefinition<"arguments" | "restParam" | "paramCountAtLeastOne" | "paramCountExactlyOne", [Readonly<{
            ignoreIdentifierPattern?: string | readonly string[];
        }> & Readonly<{
            ignorePrefixSelector?: string | readonly string[];
        }> & {
            allowRestParameter: boolean;
            allowArgumentsKeyword: boolean;
            enforceParameterCount: false | ("atLeastOne" | "exactlyOne") | {
                count: "atLeastOne" | "exactlyOne";
                ignoreLambdaExpression: boolean;
                ignoreIIFE: boolean;
                ignoreGettersAndSetters: boolean;
            };
        }]>;
        "immutable-data": RuleDefinition<"object" | "array" | "generic", [Readonly<{
            ignoreAccessorPattern?: string | readonly string[];
        }> & Readonly<{
            ignoreClasses: boolean | "fieldsOnly";
        }> & Readonly<{
            ignoreIdentifierPattern?: string | readonly string[];
        }> & {
            ignoreImmediateMutation: boolean;
            ignoreNonConstDeclarations: boolean | {
                treatParametersAsConst: boolean;
            };
        }]>;
        "no-classes": RuleDefinition<"generic", [{}]>;
        "no-conditional-statements": RuleDefinition<"incompleteBranch" | "incompleteIf" | "incompleteSwitch" | "unexpectedIf" | "unexpectedSwitch", [{
            allowReturningBranches: boolean | "ifExhaustive";
        }]>;
        "no-expression-statements": RuleDefinition<"generic", [Readonly<{
            ignoreCodePattern?: string | readonly string[];
        }> & {
            ignoreVoid: boolean;
            ignoreSelfReturning: boolean;
        }]>;
        "no-let": RuleDefinition<"generic", [Readonly<{
            ignoreIdentifierPattern?: string | readonly string[];
        }> & {
            allowInForLoopInit: boolean;
            allowInFunctions: boolean;
        }]>;
        "no-loop-statements": RuleDefinition<"generic", [{}]>;
        "no-mixed-types": RuleDefinition<"generic", [{
            checkInterfaces: boolean;
            checkTypeLiterals: boolean;
        }]>;
        "no-promise-reject": RuleDefinition<"generic", [{}]>;
        "no-return-void": RuleDefinition<"generic", [{
            allowNull: boolean;
            allowUndefined: boolean;
            ignoreInferredTypes: boolean;
        }]>;
        "no-this-expressions": RuleDefinition<"generic", [{}]>;
        "no-throw-statements": RuleDefinition<"generic", [{
            allowInAsyncFunctions: boolean;
        }]>;
        "no-try-statements": RuleDefinition<"catch" | "finally", [{
            allowCatch: boolean;
            allowFinally: boolean;
        }]>;
        "prefer-immutable-types": RuleDefinition<"returnType" | "parameter" | "variable" | "propertyImmutability" | "propertyModifier", [Readonly<{
            ignoreClasses: boolean | "fieldsOnly";
        }> & {
            enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
            ignoreInferredTypes: boolean;
            ignoreNamePattern?: string | string[];
            ignoreTypePattern?: string | string[];
        } & {
            parameters?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                ignoreClasses: boolean | "fieldsOnly";
            }> & {
                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                ignoreInferredTypes: boolean;
                ignoreNamePattern?: string | string[];
                ignoreTypePattern?: string | string[];
            }>;
            returnTypes?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                ignoreClasses: boolean | "fieldsOnly";
            }> & {
                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                ignoreInferredTypes: boolean;
                ignoreNamePattern?: string | string[];
                ignoreTypePattern?: string | string[];
            }>;
            variables?: (false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None") | Partial<Readonly<{
                ignoreClasses: boolean | "fieldsOnly";
            }> & {
                enforcement: false | import("is-immutable-type").Immutability | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating" | "None";
                ignoreInferredTypes: boolean;
                ignoreNamePattern?: string | string[];
                ignoreTypePattern?: string | string[];
            } & {
                ignoreInFunctions?: boolean;
            }>;
            fixer?: Partial<Record<"ReadonlyShallow" | "ReadonlyDeep" | "Immutable", {
                pattern: string;
                replace: string;
            } | {
                pattern: string;
                replace: string;
            }[] | undefined>>;
            suggestions?: Partial<Record<"ReadonlyShallow" | "ReadonlyDeep" | "Immutable", {
                pattern: string;
                replace: string;
            }[][] | undefined>>;
        }]>;
        "prefer-property-signatures": RuleDefinition<"generic", [{
            ignoreIfReadonlyWrapped: boolean;
        }]>;
        "prefer-readonly-type": RuleDefinition<"type" | "array" | "property" | "implicit" | "tuple", [{
            allowLocalMutation: boolean;
            allowMutableReturnType: boolean;
            checkImplicit: boolean;
            ignoreCollections: boolean;
            ignoreClass: boolean | "fieldsOnly";
            ignoreInterface: boolean;
            ignorePattern?: string | string[];
        }]>;
        "prefer-tacit": RuleDefinition<"generic", []>;
        "readonly-type": RuleDefinition<"generic" | "keyword", ["generic" | "keyword"]>;
        "type-declaration-immutability": RuleDefinition<"Less" | "AtMost" | "Exactly" | "AtLeast" | "More", [Readonly<{
            ignoreIdentifierPattern?: string | readonly string[];
        }> & {
            rules: {
                identifiers: string | string[];
                immutability: import("is-immutable-type").Immutability | "Mutable" | "ReadonlyShallow" | "ReadonlyDeep" | "Immutable" | "Calculating";
                comparator?: RuleEnforcementComparator | "Less" | "AtMost" | "Exactly" | "AtLeast" | "More";
                fixer?: false | {
                    pattern: string;
                    replace: string;
                } | {
                    pattern: string;
                    replace: string;
                }[];
            }[];
            ignoreInterfaces: boolean;
        }]>;
    };
};
export { _default as default };
